@@ -68,8 +68,13 @@ def multiplot(*args, **kwargs):
             c += ' %s,' %(cmd)
         #print("log multiplot(): ", c.rstrip(','))
         g.cmd(c.rstrip(','))
-        # multiplot automatically unset all the label after one subplot.
-        g.cmd('unset for [i=1:200] label i')
+        # multiplot automatically unset the following setting:
+        g.unset('for [i=1:200] label i',
+                'title',
+                'xtics', 'x2tics', 'ytics', 'y2tics', 'ztics', 'cbtics',
+                'xlabel', 'x2label', 'ylabel', 'y2label', 'zlabel', 'cblabel',
+                'xrange', 'x2range', 'yrange', 'y2range', 'zrange', 'cbrange',
+                'rrange', 'trange', 'urange', 'vrange')
     g.reset()
 
 def plot(*args, **kwargs):
@@ -274,6 +279,7 @@ class Gnuplot(object):
 
     def __call__(self, s):
         """Send a command string to gnuplot, followed by newline."""
+        #print(s)
         cmd = s + '\n'
         self.write(cmd.encode('utf-8'))
         self.flush()
