@@ -69,8 +69,14 @@ def multiplot(*args, **kwargs):
             c += ' $Mydata %s, ' %(cmd)
         #print(c)
         g.cmd(c)
-        # multiplot automatically unset all the label after one subplot.
-        g.cmd('unset for [i=1:50] label i')
+        # multiplot automatically unset the following setting:
+        g.unset('for [i=1:200] label i',
+                'title',
+                'xtics', 'x2tics', 'ytics', 'y2tics', 'ztics', 'cbtics',
+                'xlabel', 'x2label', 'ylabel', 'y2label', 'zlabel', 'cblabel',
+                'xrange', 'x2range', 'yrange', 'y2range', 'zrange', 'cbrange',
+                'rrange', 'trange', 'urange', 'vrange')
+
     g.reset()
 
 def plot(data, *args, **kwargs):
